#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.frozen-bubble.org/home/

NAME="frozen-bubble"
# Package version
VERSION="2.2.0"
# Source code URL
SOURCE="http://www.frozen-bubble.org/data/frozen-bubble-$VERSION.tar.bz2"
# ./configure options
CONFIGOPTIONS="--prefix=/usr"
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS COPYING INSTALL NEWS README TIPS VERSION"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="54.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: frozen-bubble - A Puzzle Bubble clone written in perl
$NAME:
$NAME: Colorful 3D rendered penguin animations, 100 levels of 1p game,
$NAME: hours and hours of 2p game, nights and nights of 2p/3p/4p/5p
$NAME: game over LAN or Internet, a level-editor, 3 professional
$NAME: quality digital soundtracks, 15 stereo sound effects, 8 unique
$NAME: graphical transition effects, 8 unique logo eye-candies.
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvjf $NAME-$VERSION.tar.bz2

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Frozen-Bubble
Exec=frozen-bubble
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
Icon=frozen-bubble
EOF

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# no configure, just make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
# Patch for proper installation dirs
sed -i -e 's,/local,,' settings.mk
sed -i -e 's,MANDIR = .*,MANDIR = $(PREFIX)/man,' settings.mk
sed -i -e 's,LOCALEDIR = .*,LOCALEDIR = $(DATADIR)/locale,' settings.mk
# Also patch for proper flags
sed -i -e 's,-O2,-O2 -march=i486 -mtune=i686,' c_stuff/Makefile.PL
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG

# Take care of the perllocal.pod file which also exists in other packages
mv $PKG/usr/lib/perl5/5.10.0/i486-linux-thread-multi/perllocal.pod $PKG/usr/lib/perl5/5.10.0/i486-linux-thread-multi/perllocal.pod.$NAME

# Create the doinst.sh script for the perllocal.pod file
cat > $PKG/install/doinst.sh << EOF
configcat() {
  NEW="usr/lib/perl5/5.10.0/i486-linux-thread-multi/perllocal.pod.\$1"
  OLD="usr/lib/perl5/5.10.0/i486-linux-thread-multi/perllocal.pod"
  # If there's no file by that name, mv it over:
  if [ ! -r "\$OLD" ]; then
    mv "\$NEW" "\$OLD"
  elif grep "fb_c_stuff" "\$OLD" &> /dev/null ; then # don't append it twice
    rm "\$NEW" &>/dev/null
  else
    cat "\$NEW" >> "\$OLD"
    rm "\$NEW"
  fi
}
configcat $NAME
EOF

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Copy icons
mkdir -p $PKG/usr/share/icons/hicolor/64x64/apps
cp $CWD/$NAME-$VERSION/icons/frozen-bubble-icon-64x64.png $PKG/usr/share/icons/hicolor/64x64/apps/frozen-bubble.png
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
cp $CWD/$NAME-$VERSION/icons/frozen-bubble-icon-48x48.png $PKG/usr/share/icons/hicolor/48x48/apps/frozen-bubble.png
mkdir -p $PKG/usr/share/icons/hicolor/32x32/apps
cp $CWD/$NAME-$VERSION/icons/frozen-bubble-icon-32x32.png $PKG/usr/share/icons/hicolor/32x32/apps/frozen-bubble.png
mkdir -p $PKG/usr/share/icons/hicolor/16x16/apps
cp $CWD/$NAME-$VERSION/icons/frozen-bubble-icon-16x16.png $PKG/usr/share/icons/hicolor/16x16/apps/frozen-bubble.png

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
/sbin/makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG

cat > $NAME-$VERSION-$ARCH-$BUILD.src << EOF
http://pnboy.pinguix.com/gapan/$NAME/build-$NAME.sh
http://www.frozen-bubble.org/data/frozen-bubble-$VERSION.tar.bz2
EOF
